@@ -26,8 +26,8 @@ $ globus bookmark rename oldname newname
 @click.argument("new_bookmark_name")
 @LoginManager.requires_login(LoginManager.TRANSFER_RS)
 def bookmark_rename(
-    *, login_manager: LoginManager, bookmark_id_or_name, new_bookmark_name
-):
+    *, login_manager: LoginManager, bookmark_id_or_name: str, new_bookmark_name: str
+) -> None:
     """Change a bookmark's name"""
     transfer_client = login_manager.get_transfer_client()
     bookmark_id = resolve_id_or_name(transfer_client, bookmark_id_or_name)["id"]
