@@ -1,6 +1,6 @@
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command, endpoint_id_arg
-from globus_cli.termio import FORMAT_TEXT_RAW, formatted_print
+from globus_cli.termio import TextMode, display
 
 
 @command(
@@ -24,4 +24,4 @@ def endpoint_deactivate(*, login_manager: LoginManager, endpoint_id: str) -> Non
     """
     transfer_client = login_manager.get_transfer_client()
     res = transfer_client.endpoint_deactivate(endpoint_id)
-    formatted_print(res, text_format=FORMAT_TEXT_RAW, response_key="message")
+    display(res, text_mode=TextMode.text_raw, response_key="message")
