@@ -2,7 +2,7 @@ import click
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command, endpoint_id_arg
-from globus_cli.termio import FORMAT_TEXT_RAW, formatted_print
+from globus_cli.termio import TextMode, display
 
 
 @command(
@@ -40,4 +40,4 @@ def update_command(*, login_manager: LoginManager, permissions, rule_id, endpoin
 
     rule_data = assemble_generic_doc("access", permissions=permissions)
     res = transfer_client.update_endpoint_acl_rule(endpoint_id, rule_id, rule_data)
-    formatted_print(res, text_format=FORMAT_TEXT_RAW, response_key="message")
+    display(res, text_mode=TextMode.text_raw, response_key="message")
