@@ -6,7 +6,7 @@ import click
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command, endpoint_id_arg
-from globus_cli.termio import FORMAT_TEXT_RAW, formatted_print
+from globus_cli.termio import TextMode, display
 
 
 class SubscriptionIdType(click.ParamType):
@@ -46,4 +46,4 @@ def set_endpoint_subscription_id(
         f"/endpoint/{endpoint_id}/subscription",
         data={"subscription_id": subscription_id},
     )
-    formatted_print(res, text_format=FORMAT_TEXT_RAW, response_key="message")
+    display(res, text_mode=TextMode.text_raw, response_key="message")
