@@ -2,33 +2,40 @@ from __future__ import annotations
 
 import click
 
+from globus_cli.constants import ExplicitNullType
 from globus_cli.login_manager import LoginManager
-from globus_cli.parsing import command, endpointish_create_and_update_params
+from globus_cli.parsing import command, endpointish_params
 from globus_cli.termio import Field, TextMode, display
 
+from ._common import deprecated_verify_option
+
 
 @command("mapped", short_help="Create a new GCP Mapped Collection")
-@endpointish_create_and_update_params("create", "collection")
+@endpointish_params.create(name="collection", keyword_style="string")
 @click.option(
     "--subscription-id",
-    help="Set the endpoint as a managed endpoint with the given subscription ID",
+    help="Set the collection as managed with the given subscription ID",
 )
+@deprecated_verify_option
 @LoginManager.requires_login(LoginManager.TRANSFER_RS)
 def mapped_command(
     *,
     login_manager: LoginManager,
     display_name: str,
-    description: str | None,
-    info_link: str | None,
-    contact_info: str | None,
-    contact_email: str | None,
-    organization: str | None,
-    department: str | None,
+    description: str | None | ExplicitNullType,
+    info_link: str | None | ExplicitNullType,
+    contact_info: str | None | ExplicitNullType,
+    contact_email: str | None | ExplicitNullType,
+    organization: str | None | ExplicitNullType,
+    department: str | None | ExplicitNullType,
     keywords: str | None,
-    default_directory: str | None,
+    default_directory: str | None | ExplicitNullType,
     force_encryption: bool | None,
-    disable_verify: bool | None,
+    verify: dict[str, bool],
     subscription_id: str | None,
+    disable_verify: bool | None,
+    user_message: str | None | ExplicitNullType,
+    user_message_link: str | None | ExplicitNullType,
 ) -> None:
     """
     Create a new Globus Connect Personal Mapped Collection.
@@ -42,6 +49,9 @@ def mapped_command(
     """
     from globus_cli.services.transfer import assemble_generic_doc
 
+    if disable_verify is not None:
+        verify["disable_verify"] = disable_verify
+
     transfer_client = login_manager.get_transfer_client()
 
     # build the endpoint document to submit
@@ -58,8 +68,10 @@ def mapped_command(
         keywords=keywords,
         default_directory=default_directory,
         force_encryption=force_encryption,
-        disable_verify=disable_verify,
         subscription_id=subscription_id,
+        user_message=user_message,
+        user_message_link=user_message_link,
+        **verify,
     )
 
     res = transfer_client.create_endpoint(ep_doc)
