@@ -6,13 +6,12 @@ import click
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import IdentityType, ParsedIdentity, command
-from globus_cli.termio import FORMAT_TEXT_RECORD, formatted_print
-from globus_cli.types import FIELD_LIST_T
+from globus_cli.termio import Field, TextMode, display
 
-JOIN_USER_FIELDS: FIELD_LIST_T = [
-    ("Group ID", "group_id"),
-    ("User ID", "identity_id"),
-    ("Username", "username"),
+JOIN_USER_FIELDS = [
+    Field("Group ID", "group_id"),
+    Field("User ID", "identity_id"),
+    Field("Username", "username"),
 ]
 
 
@@ -65,9 +64,9 @@ def group_join(
         except LookupError:
             raise ValueError("Could not join group")
 
-    formatted_print(
+    display(
         response,
-        text_format=FORMAT_TEXT_RECORD,
+        text_mode=TextMode.text_record,
         fields=JOIN_USER_FIELDS,
         response_key=lambda data: data[action][0],
     )
