@@ -2,7 +2,7 @@ import click
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command, endpoint_id_arg
-from globus_cli.termio import FORMAT_TEXT_RAW, formatted_print
+from globus_cli.termio import TextMode, display
 
 
 @command(
@@ -38,4 +38,4 @@ def rename_command(*, login_manager: LoginManager, endpoint_id, source, destinat
     res = transfer_client.operation_rename(
         endpoint_id, oldpath=source, newpath=destination
     )
-    formatted_print(res, text_format=FORMAT_TEXT_RAW, response_key="message")
+    display(res, text_mode=TextMode.text_raw, response_key="message")
