@@ -1,15 +1,15 @@
 from __future__ import annotations
 
 import json
+import typing as t
 import uuid
 from io import TextIOWrapper
-from typing import Any
 
 import click
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command, mutex_option_group
-from globus_cli.termio import FORMAT_TEXT_RECORD, formatted_print
+from globus_cli.termio import Field, TextMode, display, formatters
 
 from ._common import index_id_arg
 
@@ -49,7 +49,7 @@ def delete_by_query_command(
     search_client = login_manager.get_search_client()
 
     if q:
-        doc: dict[str, Any] = {"q": q}
+        doc: dict[str, t.Any] = {"q": q}
     elif query_document:
         doc = json.load(query_document)
     else:
@@ -59,11 +59,17 @@ def delete_by_query_command(
         doc["advanced"] = advanced
 
     data = search_client.delete_by_query(index_id, doc)
-    formatted_print(
+    display(
         data,
-        text_format=FORMAT_TEXT_RECORD,
+        text_mode=TextMode.text_record,
         fields=[
-            ("Message", lambda _x: "delete-by-query task successfully submitted"),
-            ("Task ID", "task_id"),
+            Field(
+                "Message",
+                "@",
+                formatter=formatters.StaticStringFormatter(
+                    "delete-by-query task successfully submitted"
+                ),
+            ),
+            Field("Task ID", "task_id"),
         ],
     )
