@@ -2,7 +2,7 @@ import uuid
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command
-from globus_cli.termio import FORMAT_TEXT_RECORD, formatted_print
+from globus_cli.termio import TextMode, display
 
 from .._common import INDEX_FIELDS, index_id_arg
 
@@ -13,8 +13,8 @@ from .._common import INDEX_FIELDS, index_id_arg
 def show_command(*, login_manager: LoginManager, index_id: uuid.UUID):
     """Display information about an index"""
     search_client = login_manager.get_search_client()
-    formatted_print(
+    display(
         search_client.get_index(index_id),
-        text_format=FORMAT_TEXT_RECORD,
+        text_mode=TextMode.text_record,
         fields=INDEX_FIELDS,
     )
