@@ -10,9 +10,9 @@ from ._common import DELETED_JOB_FORMAT_FIELDS
 
 
 @command("delete", short_help="Delete a timer job", hidden=True)
-@click.argument("JOB_ID", type=uuid.UUID)
+@click.argument("JOB_ID", type=click.UUID)
 @LoginManager.requires_login(LoginManager.TIMER_RS)
-def delete_command(login_manager: LoginManager, job_id: uuid.UUID):
+def delete_command(*, login_manager: LoginManager, job_id: uuid.UUID) -> None:
     """
     Delete a Timer job.
 
