@@ -1,3 +1,5 @@
+import uuid
+
 import click
 
 from globus_cli.login_manager import LoginManager
@@ -8,9 +10,9 @@ from ._common import JOB_FORMAT_FIELDS
 
 
 @command("show", short_help="Display a Timer job")
-@click.argument("JOB_ID")
+@click.argument("JOB_ID", type=click.UUID)
 @LoginManager.requires_login(LoginManager.TIMER_RS)
-def show_command(login_manager: LoginManager, job_id: str):
+def show_command(*, login_manager: LoginManager, job_id: uuid.UUID) -> None:
     """
     Display information about a particular job.
     """
