@@ -1,3 +1,4 @@
+from .annotated_param import AnnotatedParamType
 from .comma_delimited import CommaDelimitedList
 from .endpoint_plus_path import (
     ENDPOINT_PLUS_OPTPATH,
@@ -6,12 +7,14 @@ from .endpoint_plus_path import (
 )
 from .identity_type import IdentityType, ParsedIdentity
 from .location import LocationType
+from .notify_param import NotificationParamType
 from .nullable import StringOrNull, UrlOrNull, nullable_multi_callback
 from .prefix_mapper import JSONStringOrFile
 from .task_path import TaskPath
 from .timedelta import TimedeltaType
 
 __all__ = (
+    "AnnotatedParamType",
     "CommaDelimitedList",
     "ENDPOINT_PLUS_OPTPATH",
     "ENDPOINT_PLUS_REQPATH",
@@ -22,6 +25,7 @@ __all__ = (
     "StringOrNull",
     "UrlOrNull",
     "nullable_multi_callback",
+    "NotificationParamType",
     "JSONStringOrFile",
     "TaskPath",
     "TimedeltaType",
